==> Paws-0.36.tar.gz: Paws-0.36/lib/Paws/Lightsail/GetInstances.pm <==

package Paws::Lightsail::GetInstances;
  use Moose;
  has PageToken => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'pageToken' );

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetInstances');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Lightsail::GetInstancesResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Lightsail::GetInstances - Arguments for method GetInstances on Paws::Lightsail

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetInstances on the 
Amazon Lightsail service. Use the attributes of this class
as arguments to method GetInstances.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetInstances.

As an example:

  $service_obj->GetInstances(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 PageToken => Str

A token used for advancing to the next page of results from your get
instances request.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetInstances in L<Paws::Lightsail>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.43.tar.gz: Paws-0.43/lib/Paws/Lightsail/GetInstances.pm <==

package Paws::Lightsail::GetInstances;
  use Moose;
  has PageToken => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'pageToken' );

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetInstances');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Lightsail::GetInstancesResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Lightsail::GetInstances - Arguments for method GetInstances on L<Paws::Lightsail>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetInstances on the
L<Amazon Lightsail|Paws::Lightsail> service. Use the attributes of this class
as arguments to method GetInstances.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetInstances.

=head1 SYNOPSIS

    my $lightsail = Paws->service('Lightsail');
    my $GetInstancesResult = $lightsail->GetInstances(
      PageToken => 'Mystring',    # OPTIONAL
    );

    # Results:
    my $Instances     = $GetInstancesResult->Instances;
    my $NextPageToken = $GetInstancesResult->NextPageToken;

    # Returns a L<Paws::Lightsail::GetInstancesResult> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/lightsail/GetInstances>

=head1 ATTRIBUTES


=head2 PageToken => Str

A token used for advancing to the next page of results from your get
instances request.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetInstances in L<Paws::Lightsail>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
